Search.setIndex({objnames:{},titleterms:{indic:[],set:0,raspberri:0,home:[0,1],view:0,quickstart:0,assumpt:0,run:0,tabl:[],welcom:1,document:1,instal:0,data:0},objects:{},terms:{stuff:0,opt:0,search:[],seri:0,repositori:0,still:0,know:0,compil:0,step:0,record:0,dev:0,rfxcom_rfxtrx433_a1wyt9na:0,now:0,isn:0,danger:0,what:0,packag:0,realli:0,same:0,raspbian:0,other:0,moment:1,raspberri:[],local:0,path:0,perform:0,librari:[0,1],tell:0,quick:0,order:0,upgrad:0,syncdb:0,got:0,where:0,your:[0,1],from:0,apt:0,data_point:0,python3:0,page:[],onli:0,bashrc:0,version:0,pip:0,rfxcom:0,than:0,command:0,electr:0,full:0,limit:1,virtualenv:0,desc:0,under:0,ssh:0,serial:0,vim:0,exactli:0,sourc:0,mkvirtualenv:0,activ:0,after:0,out:0,have:0,referenc:0,latest:0,network:0,ask:0,rfxtrx:0,git:0,created_at:0,virtualenvwrapp:0,set:[],password:0,tox:0,each:0,cm160:0,raspberrypi:0,trust:0,see:0,hydro:0,port0:0,"function":1,much:0,abl:0,psql:0,oregon:0,bin:0,scientif:0,manag:1,receiv:0,ghetto:0,valu:0,usb:0,rather:0,sinc:0,last:0,get:0,autom:1,join:0,screen:0,respbian:[],everyth:0,device_id:0,fresh:0,small:0,thermo:0,owl:0,requir:0,log:0,deploi:0,content:1,stage:1,modul:[],need:0,oper:0,if00:0,first:0,shouldn:0,mean:0,all:0,unix:0,index:[],when:0,make:0,suggest:0,setup:[0,1],right:0,name:0,output:0,select:0,thgn132n:0,should:0,add:0,series_id:0,sumamri:0,current:0,work:0,yet:0,sensor:0,otherwis:0,thi:0,number:0,devic:0,org:0,system:0,earli:1,updat:0,interest:0,group:0,veri:1,block:0,assum:0,session:0,store:0,"new":0,abov:0,min:0,point:0,thing:0,run:[],time:0,how:0,explor:0,postgr:0,support:0,most:0,report:0,doe:0,rel:0,let:0,max:0,obvious:0,packet:0,chang:0,collect:0,download:0,copi:0,base:0,mani:0,databas:0,host:0,more:0,start:0,python:[0,1],done:0,show:0,find:0,fine:0,connect:0,listen:0,probabl:0,http:0,basic:0,workon:0,some:0,match:0,count:0,follow:0,close:0,you:0,bootstrap:0,script:0,can:0,privat:0,raspbian_latest:0},titles:["Quickstart for Installing home","Welcome to home&#8217;s documentation!"],filenames:["quickstart","index"],envversion:43,objtypes:{}})